@@ -13,7 +13,8 @@ import datetime
 
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
 
-API_GW = "https://ck78dwtl1j.execute-api.cn-north-1.amazonaws.com.cn/api/"
+API_GW = "https://htfj7ow5x8.execute-api.cn-north-1.amazonaws.com.cn/api/"
+
 
 def get_message():
     return HELLO_WORLD_MESSAGE
@@ -77,10 +78,10 @@ def create_training_job(local_data, source_code, weights, hyper_param):
     }
     hyper_param.update({"jobid": job_id})
     payload = json.dumps(hyper_param)
-    print(f"payload {payload}")
+    #print(f"payload {payload}")
     response = requests.request("POST", f"{API_GW}/job", headers=headers, data=payload)
 
-    print(response)
+    #print(response)
     get_training_job_logstream(job_id)
     return job_id
 
@@ -99,6 +100,7 @@ def get_training_job_status(job_id):
     response = requests.request("GET", url)
     #print(f"response {response}")
     response_body = json.loads(response.text)
+    #print(response.text)
     if len(response_body) == 2:
         return print("waiting...")
     else:
@@ -113,7 +115,7 @@ def get_model(job_id, model):
     response = requests.get(url, allow_redirects=True)
 
     response_s3 = requests.get(response.__dict__['_content'])
-    print(f"getting {url}")
+    #print(f"getting {url}")
 
     if response.status_code == 200:
         size = 2**10
@@ -125,7 +127,7 @@ def get_model(job_id, model):
 
 def get_training_job_logstream(job_id):
     url = f"{API_GW}/jobs/{job_id}"
-    print(f"getting {url}")
+    #print(f"getting {url}")
 
     tmp_status = ["Completed", "Failed", "Stopped"]
     headers = {
@@ -206,11 +208,11 @@ def __upload_one_file(job_id, type, object_name):
     # request a s3 presigned URL
     object_name_encoded = path_encoder.quote(object_name, safe="") # by default / is recognized as safe
     url = f"{API_GW}/s3url/{job_id}/{type}/{object_name_encoded}"
-    #print(f"getting {url}")
+    #print(f"getting url: {url}")
     response = requests.request("GET", url)
-    #print(f"response {response}")
+    #print(f"response: {response}")
     response_body = json.loads(response.text)
-
+    #print(f"response_body: {response_body}")
 
     with open(object_name, 'rb') as f:
         files = {'file': (object_name, f)}
@@ -245,7 +247,8 @@ if __name__ == "__main__":
                         {"instance_type":"ml.p3.2xlarge",
                         "instance_count":"1",
                         "framework_version":"1.8.1",
-                        "hyperparameters":{"imgsz":"640", "epochs":"100"}})
+                        "hyperparameters":{"imgsz":"64", "epochs":"10"}})
+    
     
     #make_tar("train.py")
     #s3://code-devcloud/jobs/090e3c81-804a-4a34-abfb-33d67d77bfa8/Traindata/mnist/
@@ -255,6 +258,6 @@ if __name__ == "__main__":
                         None,
                         {"instance_type":"ml.m5.xlarge",
                         "instance_count":"1",
-                        "framework_version":"1.1.0",
+                        "framework_version":"1.1.0",   
                         "hyperparameters":{"epochs":"4","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
     """
